
# Slot: slot_uri


predicate of this slot for semantic web application

URI: [linkml:slot_uri](https://w3id.org/linkml/slot_uri)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
